@@ -2,7 +2,7 @@
 //
 //  RQuantLib -- R interface to the QuantLib libraries
 //
-//  Copyright (C) 2002 - 2014  Dirk Eddelbuettel 
+//  Copyright (C) 2002 - 2017  Dirk Eddelbuettel 
 //  Copyright (C) 2005 - 2006  Dominick Samperi
 //  Copyright (C) 2009 - 2012  Dirk Eddelbuettel and Khanh Nguyen
 //
@@ -379,8 +379,10 @@ QuantLib::DayCounter getDayCounter(const double n){
         return QuantLib::SimpleDayCounter();
     else if (n==6)
         return QuantLib::Thirty360();
-    else if (n==7)
-        return QuantLib::Actual365NoLeap();
+#ifdef RQUANTLIB_USE_ACTUAL365NOLEAP
+     else if (n==7)
+         return QuantLib::Actual365NoLeap();
+#endif    
     else if (n==8)
         return QuantLib::ActualActual(QuantLib::ActualActual::ISMA);
     else if (n==9)
@@ -404,6 +406,12 @@ QuantLib::BusinessDayConvention getBusinessDayConvention(const double n){
         return QuantLib::Preceding;
     else if (n==3) 
         return QuantLib::ModifiedPreceding;
+    else if (n==4)
+        return QuantLib::Unadjusted;
+    else if (n==5)
+        return QuantLib::HalfMonthModifiedFollowing;
+    else if (n==6)
+        return QuantLib::Nearest;
     else  
         return QuantLib::Unadjusted;
 }
@@ -482,6 +490,12 @@ QuantLib::DateGeneration::Rule getDateGenerationRule(const double n){
         return QuantLib::DateGeneration::ThirdWednesday;
     else if (n==4) 
         return QuantLib::DateGeneration::Twentieth;
+    else if (n==5)
+        return QuantLib::DateGeneration::TwentiethIMM;
+    else if (n==6)
+        return QuantLib::DateGeneration::OldCDS;
+    else if (n==7)
+        return QuantLib::DateGeneration::CDS;
     else 
         return QuantLib::DateGeneration::TwentiethIMM;
 }
@@ -609,3 +623,50 @@ QuantLib::Duration::Type getDurationType(const double n) {
         throw std::range_error("Invalid duration type " + boost::lexical_cast<std::string>(n));
     }
 }
+
+//' This function returns the QuantLib version string as encoded in the header
+//' file \code{config.hpp} and determined at compilation time of the QuantLib library. 
+//'
+//' @title Return the QuantLib version number
+//' @return A character variable
+//' @references \url{http://quantlib.org} for details on \code{QuantLib}.
+//' @author Dirk Eddelbuettel
+//' @examples
+//'   getQuantLibVersion()
+// [[Rcpp::export]]
+std::string getQuantLibVersion() {
+    return std::string(QL_PACKAGE_VERSION);
+}
+
+//' This function returns a named vector of boolean variables describing several
+//' configuration options determined at compilation time of the QuantLib library. 
+//'
+//' Not all of these features are used (yet) by RQuantLib.
+//' @title Return configuration options of the QuantLib library
+//' @return A named vector of logical variables
+//' @references \url{http://quantlib.org} for details on \code{QuantLib}.
+//' @author Dirk Eddelbuettel
+//' @examples
+//'   getQuantLibCapabilities()
+// [[Rcpp::export]]
+Rcpp::LogicalVector getQuantLibCapabilities() {
+    bool hasSessions = false,        	// not (yet?) used by RQuantLib
+        hasHighResolutionDate=false,    // supported as of RQuantLib 0.4.2
+        hasNegativeRates=false;         // not explicitly supported or denied
+
+#ifdef QL_ENABLE_SESSIONS    
+    hasSessions = true;
+#endif
+
+#ifdef QL_HIGH_RESOLUTION_DATE
+    hasHighResolutionDate=true;
+#endif
+
+#ifdef QL_NEGATIVE_RATES
+    hasNegativeRates=true;
+#endif
+
+    return Rcpp::LogicalVector::create(Rcpp::Named("sessions") = hasSessions,
+                                       Rcpp::Named("intradayDate") = hasHighResolutionDate,
+                                       Rcpp::Named("negativeRates") = hasNegativeRates);
+}
